pyprocar.plotter.EBSPlot — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.plotter.EBSPlot

class pyprocar.plotter.EBSPlot(ebs: ElectronicBandStructure, kpath: KPath | None = None, ax: Axes | None = None, spins: List[int] | None = None, kdirect: bool = True, config=None)

  A class to plot an electronic band structure.

  Parameters:

    - ebs (ElectronicBandStructure) – An electronic band structure object pyprocar.core.ElectronicBandStructure.

    - kpath (KPath, optional) – A kpath object pyprocar.core.KPath. The default is None.

    - ax (mpl.axes.Axes, optional) – A matplotlib Axes object. If provided the plot will be located at that ax. The default is None.

    - spin (List[int], optional) – A list of the spins The default is None.

  Returns:

    None.

  Methods

  `EBSPlot.__init__`(ebs[, kpath, ax, spins, ...]) |
  `EBSPlot.draw_fermi`([fermi_level]) | A method to draw the fermi line
  `EBSPlot.export_data`(filename) | This method will export the data to a csv file
  `EBSPlot.grid`() | A method to plot a grid
  `EBSPlot.legend`([labels]) | A methdo to plot the legend
  `EBSPlot.plot_atomic_levels`([spins, ...]) | A method to plot a scatter plot
  `EBSPlot.plot_bands`() | Plot the plain band structure.
  `EBSPlot.plot_parameteric`([spins, ...]) | A method to plot a scatter plot
  `EBSPlot.plot_parameteric_overlay`([spins, ...]) | A method to plot the parametric overlay
  `EBSPlot.plot_scatter`([width_mask, ...]) | A method to plot a scatter plot
  `EBSPlot.save`([filename]) | A method to save the plot
  `EBSPlot.set_colorbar_title`([title]) | A method to set the title of the color bar
  `EBSPlot.set_title`([title]) | A method to set the title
  `EBSPlot.set_xlabel`([label]) | A method to set the x label
  `EBSPlot.set_xlim`([interval]) | A method to set the x limit
  `EBSPlot.set_xticks`([tick_positions, ...]) | A method to set the x ticks
  `EBSPlot.set_ylabel`([label]) | A method to set the y label
  `EBSPlot.set_ylim`([interval]) | A method to set the y limit
  `EBSPlot.set_yticks`([major, minor, interval]) | A method to set the y ticks
  `EBSPlot.show`() | A method to show the plot